@@ -13,6 +13,12 @@ pub struct Set {
     auth: Option<String>,
     #[structopt(short, long, help = "The TTL for the nodes cache file in seconds")]
     cache_ttl: Option<u64>,
+    #[structopt(
+        short,
+        long,
+        help = "A list of labels that should be shown. If none is set all labels will be shown"
+    )]
+    label_whitelist: Option<Vec<String>>,
 }
 
 impl Set {
@@ -35,6 +41,10 @@ impl Set {
             config.auth = Some(auth.clone());
         }
 
+        if let Some(label_whitelist) = &self.label_whitelist {
+            config.label_whitelist = Some(label_whitelist.clone());
+        }
+
         config.write()?;
 
         Ok(())
